@@ -2,11 +2,11 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2023-02-06 13:43:27
+@LastEditTime: 2023-02-10 09:52:14
 @LastEditors: HuangJianYi
 @Description: 
 """
-from operator import truediv
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.libs.customize.seven_helper import SevenHelper
 from seven_cloudapp_frame.libs.customize.wechat_helper import WeChatPayRequest, WeChatPayReponse, WeChatRefundReponse
 from seven_cloudapp_frame.libs.customize.tiktok_helper import TikTokPayRequest, TikTokReponse
@@ -43,7 +43,7 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
         pay_order = pay_order_model.get_entity("pay_order_no=%s", params=[pay_order_no])
         if not pay_order or pay_order.order_status != 0:
             return self.response_json_error("error", "抱歉!未查询到订单信息,请联系客服")
-        pay_config = config.get_value("wechat_pay")
+        pay_config = share_config.get_value("wechat_pay")
         pay_notify_url = pay_config["pay_notify_url"]
 
         # 商品说明
@@ -230,7 +230,7 @@ class TiktokVoucherOrderHandler(ClientBaseHandler):
         pay_order = pay_order_model.get_entity("pay_order_no=%s", params=[pay_order_no])
         if not pay_order or pay_order.order_status != 0:
             return self.response_json_error("error", "抱歉!未查询到订单信息,请联系客服")
-        pay_config = config.get_value("tiktok_pay")
+        pay_config = share_config.get_value("tiktok_pay")
         pay_notify_url = pay_config["pay_notify_url"]
         # 商品描述
         subject = pay_order.order_name
@@ -424,9 +424,9 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
         sub_b_type_list = invoke_result_data.data["sub_b_type_list"] if invoke_result_data.data.__contains__("sub_b_type_list") else [] #下单场景，默认全部
         try:
             third_pay_order_model = ThirdPayOrderModel(context=self)
-            shop_id = config.get_value("shake_shop")["shop_id"]
-            app_key = config.get_value("shake_shop")["app_key"]
-            app_secret = config.get_value("shake_shop")["app_secret"]
+            shop_id = share_config.get_value("shake_shop")["shop_id"]
+            app_key = share_config.get_value("shake_shop")["app_key"]
+            app_secret = share_config.get_value("shake_shop")["app_secret"]
             shakeshop_base_model = ShakeShopBaseModel(self, app_key, app_secret, "SELF", None, shop_id)
             result = shakeshop_base_model.callback(self.request.headers, self.request.body, is_log=False)
             if result:
