@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:15:49
-@LastEditTime: 2022-07-19 10:53:47
+@LastEditTime: 2023-03-13 11:37:23
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -50,6 +50,8 @@ class SaveThemeHandler(ClientBaseHandler):
         :param server_json：服务端内容json
         :param out_id：外部id
         :param ver_no：客户端版本号
+        :param style_type：样式类型
+        :param ascription_type：归属类型(1公共)
         :return: 
         :last_editors: HuangJianYi
         """
@@ -60,9 +62,10 @@ class SaveThemeHandler(ClientBaseHandler):
         out_id = self.get_param("out_id")
         ver_no = self.get_param("ver_no")
         style_type = int(self.get_param("style_type",0))
+        ascription_type = self.get_param_int("ascription_type",1)
 
         theme_base_model = ThemeBaseModel(context=self)
-        theme_base_model.save_theme(app_id, theme_name, client_json, server_json, out_id, ver_no, style_type)
+        theme_base_model.save_theme(app_id, theme_name, client_json, server_json, out_id, ver_no, style_type, ascription_type)
         return self.response_json_success()
 
 
