@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2023-02-15 13:33:05
+@LastEditTime: 2023-03-03 14:54:15
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -326,6 +326,7 @@ class AssetLogListHandler(ClientBaseHandler):
         """
         :description: 资产流水记录
         :param act_id：活动标识
+        :param module_id：模块标识
         :param user_code：用户标识
         :param asset_type：资产类型(1-次数2-积分3-价格档位))
         :param asset_object_id：资产对象标识
@@ -339,6 +340,7 @@ class AssetLogListHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
+        module_id = self.get_param_int("module_id", 0)
         page_index = self.get_param_int("page_index", 0)
         page_size = self.get_param_int("page_size", 20)
         asset_type = self.get_param_int("asset_type", 0)
@@ -354,7 +356,7 @@ class AssetLogListHandler(ClientBaseHandler):
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         asset_base_model = AssetBaseModel(context=self)
         page_count_mode = SevenHelper.get_enum_key(PageCountMode, page_count_mode)
-        page_list = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, field=field, is_cache=True, operate_type=operate_type, page_count_mode=page_count_mode)
+        page_list = asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, field=field, is_cache=True, operate_type=operate_type, page_count_mode=page_count_mode, module_id=module_id)
         if page_count_mode == "total":
             total = page_list[1]
             page_list = self.business_process_executed(page_list[0], ref_params={})
