@@ -107,14 +107,7 @@ class VersionUpgradeHandler(ClientBaseHandler):
 
         base_info = BaseInfoModel(context=self).get_entity()
         client_ver = base_info.client_ver
-
-        #中台指定账号升级
-        version_info = VersionInfoModel(context=self).get_entity(where="type_id=1",order_by="id desc")
-        if version_info:
-            if version_info.update_scope == 2 and version_info.white_lists:
-                white_lists = list(set(str(version_info.white_lists).split(',')))
-                if user_nick in white_lists:
-                    client_ver = version_info.version_number
+        store_user_nick = user_nick.split(':')[0]
 
         app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
         if not app_info:
@@ -123,9 +116,17 @@ class VersionUpgradeHandler(ClientBaseHandler):
         test_client_ver = test_config.get("client_ver","")
         client_template_id = share_config.get_value("client_template_id")
         #配置文件指定账号升级
-        store_user_nick = user_nick.split(':')[0]
         if test_client_ver and store_user_nick and store_user_nick == test_config.get("user_nick",""):
             client_ver = test_client_ver
+        else:
+            #中台指定账号升级
+            version_info = VersionInfoModel(context=self).get_entity(where="type_id=1",order_by="id desc")
+            if version_info:
+                if version_info.update_scope == 2 and version_info.white_lists:
+                    white_lists = SevenHelper.json_loads(version_info.white_lists)
+                    if store_user_nick in white_lists:
+                        client_ver = version_info.version_number
+
         top_base_model = TopBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
         invoke_result_data = top_base_model.version_upgrade(app_id, client_template_id, client_ver, access_token,app_key, app_secret, app_info, is_log)
