@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2023-01-12 09:47:34
+@LastEditTime: 2023-03-13 11:48:10
 @LastEditors: HuangJianYi
 @Description: 小活动模块（机台）
 """
@@ -25,6 +25,7 @@ class SaveActModuleHandler(ClientBaseHandler):
         :param module_id: 活动模块标识
         :param module_name: 模块名称
         :param module_sub_name: 模块短名称
+        :param module_type: 模块类型
         :param start_date: 开始时间
         :param end_date: 结束时间
         :param module_pic: 模块图片
@@ -56,6 +57,7 @@ class SaveActModuleHandler(ClientBaseHandler):
         module_id = int(self.get_param("module_id",0))
         module_name = self.get_param("module_name")
         module_sub_name = self.get_param("module_sub_name")
+        module_type = self.get_param_int("module_type",0)
         start_date = self.get_param("start_date", "1900-01-01 00:00:00")
         end_date = self.get_param("end_date", "1900-01-01 00:00:00")
         module_pic = self.get_param("module_pic")
@@ -89,7 +91,7 @@ class SaveActModuleHandler(ClientBaseHandler):
             default_prefix = "活动"
         title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else default_prefix
         module_base_model = ModuleBaseModel(context=self)
-        invoke_result_data = module_base_model.save_act_module(app_id, act_id, module_id, module_name, module_sub_name, start_date, end_date, module_pic, module_desc, price, price_gear_id, ip_id, join_ways, is_fictitious, sort_index, is_release, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, business_type)
+        invoke_result_data = module_base_model.save_act_module(app_id, act_id, module_id, module_name, module_sub_name, start_date, end_date, module_pic, module_desc, price, price_gear_id, ip_id, join_ways, is_fictitious, sort_index, is_release, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, business_type, module_type)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
