@@ -140,6 +140,7 @@ class ActPrizeListHandler(ClientBaseHandler):
         :param module_id：活动模块标识
         :param prize_name：奖品名称
         :param is_del：是否回收站1是0否
+        :param ascription_type：归属类型
         :param page_index：页索引
         :param page_size：页大小
         :return: PageInfo
@@ -150,6 +151,7 @@ class ActPrizeListHandler(ClientBaseHandler):
         module_id = int(self.get_param("module_id", 0))
         prize_name = self.get_param("prize_name")
         is_del = int(self.get_param("is_del", -1))
+        ascription_type = self.get_param_int("ascription_type", -1)
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
@@ -165,7 +167,7 @@ class ActPrizeListHandler(ClientBaseHandler):
         if not app_id or not act_id:
             return self.response_json_success({"data": []})
         prize_base_model = PrizeBaseModel(context=self)
-        page_list, total = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params, field=field, is_cache=False)
+        page_list, total = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, ascription_type, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params, field=field, is_cache=False)
         for page in page_list:
             if page.__contains__("prize_detail_json"):
                 page["prize_detail_json"] = SevenHelper.json_loads(page["prize_detail_json"]) if page["prize_detail_json"] else []
