@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2023-03-07 15:50:43
+@LastEditTime: 2023-03-17 13:48:55
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -30,7 +30,7 @@ class SevenHelper:
         :return: redis_cli
         :last_editors: HuangJianYi
         """
-        return RedisExHelper.init(db, config_dict, decode_responses)
+        return RedisExHelper.init(config_dict, decode_responses)
 
     @classmethod
     def is_continue_request(self, cache_key, expire=500):
@@ -132,13 +132,11 @@ class SevenHelper:
             if info_list:
                 source_dict = dict(source_dict, **dict.fromkeys(list_key))
                 for item in list_key:
-                    source_dict[item] = info_list[0].get(item)
+                    source_dict[item] = info_list[0].get(item,'')
             else:
-                result_key = []
                 for item in list_key:
                     if item not in source_dict.keys():
-                        result_key.append(item)
-                source_dict = dict(source_dict, **dict.fromkeys(result_key))
+                        source_dict[item] = ''
             result.append(source_dict)
         return result
 
