@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-01-14 10:44:07
-@LastEditTime: 2022-07-13 13:35:15
+@LastEditTime: 2023-02-10 09:59:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -11,6 +11,7 @@ import json
 import hashlib
 from Crypto.Cipher import AES
 import base64
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_framework.base_model import *
 from seven_cloudapp_frame.models.seven_model import InvokeResultData
@@ -33,8 +34,8 @@ class TikTokHelper:
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
 
         invoke_result_data = InvokeResultData()
         redis_key = f"{app_id}_tiktok_login_code:{code}"
@@ -84,8 +85,8 @@ class TikTokHelper:
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
 
         invoke_result_data = InvokeResultData()
         param = {
@@ -94,7 +95,7 @@ class TikTokHelper:
             'grant_type': grant_type,
         }
         response = None
-        redis_init = SevenHelper.redis_init(config_dict=config.get_value("platform_redis"))
+        redis_init = SevenHelper.redis_init(config_dict=share_config.get_value("platform_redis"))
         redis_key = f"tiktok_access_token:{str(app_id)}"
         try:
             access_token = redis_init.get(redis_key)
@@ -133,8 +134,8 @@ class TikTokHelper:
         :return: 解密后的数据，用户信息或者手机号信息
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
-        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
 
         data = {}
         if code:
@@ -160,7 +161,7 @@ class TikTokHelper:
         :return: 解密后的数据，用户信息或者手机号信息
         :last_editors: HuangJianYi
         """
-        app_id = app_id if app_id else config.get_value("app_id")
+        app_id = app_id if app_id else share_config.get_value("app_id")
 
         data = {}
         try:
@@ -236,8 +237,8 @@ class TikTokPayRequest(object):
         :description: 初始化
         :last_editors: HuangJianYi
         """
-        pay_config = config.get_value("tiktok_pay")
-        self.app_id = app_id if app_id else config.get_value("app_id")
+        pay_config = share_config.get_value("tiktok_pay")
+        self.app_id = app_id if app_id else share_config.get_value("app_id")
         self.cp_extra = cp_extra if cp_extra else pay_config["cp_extra"]
         self.token = token if token else pay_config["token"]
         self.salt = salt if salt else pay_config["salt"]
@@ -574,7 +575,7 @@ class TikTokReponse(object):
 
     def __init__(self, data, token=""):
         self.data = json.loads(data)  #data由json.loads(self.request.body)获得
-        pay_config = config.get_value("tiktok_pay")
+        pay_config = share_config.get_value("tiktok_pay")
         self.token = token if token else pay_config["token"]
 
     def get_data(self):
