@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2023-03-24 16:59:12
+@LastEditTime: 2023-03-28 15:54:27
 @LastEditors: HuangJianYi
 :Description: 数据缓存业务模型
 """
@@ -77,7 +77,9 @@ class CacheModel(BaseModel):
         :return: 依赖缓存值
         :last_editors: HuangJianYi
         """
-        dependency_cache_key = self.get_dependency_cache_key(dependency_key,cache_key)
+        if share_config.get_value("is_redis_cache",True) == False:
+            return None
+        dependency_cache_key = self.get_dependency_cache_key(dependency_key, cache_key)
         redis_init = self.__redis_init()
         dependency_date_value = redis_init.get(dependency_key)
         if not dependency_date_value:
@@ -98,13 +100,28 @@ class CacheModel(BaseModel):
         cache_data = redis_init.get(dependency_cache_key)
         if not cache_data:
             return None
-        elif cache_data == 'null':
-            return cache_data
-        elif cache_data == '0':
+        elif cache_data in ['null','0']:
             return cache_data
         else:
             cache_data = json.loads(cache_data)
             return cache_data
+        
+    def log_cache(self, dependency_key, cache_key, cache_data, sql, params):
+        """
+        :Description: 记录从缓存取到的数据到日志
+        :param dependency_key: dependency_key
+        :param cache_key: cache_key
+        :param cache_data: 缓存数据
+        :param sql: sql
+        :param params: params
+        :return:
+        :last_editors: HuangJianYi
+        """
+        if hasattr(self, "db") and share_config.get_value("log_redis_cache",True):
+            if hasattr(self.db, "context"):
+                if hasattr(self.db.context, "logging_link_info"):
+                    log_info = {"sql":sql, "params":params, "result":cache_data, "dependency_key":dependency_key, "cache_key":cache_key}
+                    self.db.context.logging_link_info("data_cache:" + JsonHelper.json_dumps(log_info))
 
     def set_dependency_cache(self, dependency_key, cache_key, value, cache_expire):
         """
@@ -127,7 +144,7 @@ class CacheModel(BaseModel):
         redis_init.set(dependency_cache_key + "_savetime",str(TimeHelper.get_now_format_time()),ex=cache_expire)
         return redis_init.set(dependency_cache_key,JsonHelper.json_dumps(value),ex=cache_expire)
 
-    def __redis_init(self, db=None, decode_responses=True):
+    def __redis_init(self, decode_responses=True):
         """
         :description: redis初始化
         :return: redis_cli
@@ -136,12 +153,8 @@ class CacheModel(BaseModel):
         cache_redis = config.get_value("cache_redis")
         if not cache_redis:
             cache_redis = config.get_value("redis")
-        host = cache_redis["host"]
-        port = cache_redis["port"]
-        if not db:
-            db = cache_redis["db"]
-        password = cache_redis["password"]
-        redis_cli = RedisHelper.redis_init(host, port, db, password, decode_responses=decode_responses)
+  
+        redis_cli = RedisHelper.redis_init(config_dict=cache_redis, decode_responses=decode_responses)
         return redis_cli
 
     def delete_dependency_key(self, dependency_key='', delay_delete_time=0.01):
@@ -204,6 +217,7 @@ class CacheModel(BaseModel):
         cache_key = self.get_cache_key('entitylist',field,where,group_by,order_by,limit,params)
         list_row = self.get_dependency_cache(dependency_key,cache_key)
         if list_row and share_config.get_value("is_redis_cache",True) == True:
+            self.log_cache(dependency_key, cache_key, list_row, sql, params)
             if list_row == 'null':
                 return []
             return self._BaseModel__row_entity_list(list_row)
@@ -248,6 +262,7 @@ class CacheModel(BaseModel):
         cache_key = self.get_cache_key('entitypagelist',field,where,group_by,order_by,limit,params)
         page_list = self.get_dependency_cache(dependency_key,cache_key)
         if page_list and share_config.get_value("is_redis_cache",True) == True:
+            self.log_cache(dependency_key, cache_key, page_list, sql, params)
             if page_count_mode == "total":
                 return self._BaseModel__row_entity_list(page_list["data"]),page_list["row_count"]
             elif page_count_mode == "next":
@@ -309,6 +324,7 @@ class CacheModel(BaseModel):
         cache_key = self.get_cache_key('entity','*',where,group_by,order_by,'1',params)
         one_row = self.get_dependency_cache(dependency_key,cache_key)
         if one_row and share_config.get_value("is_redis_cache",True) == True:
+            self.log_cache(dependency_key, cache_key, one_row, sql, params)
             if one_row == 'null':
                 return None
             return self._BaseModel__row_entity(one_row)
@@ -337,6 +353,7 @@ class CacheModel(BaseModel):
         cache_key = self.get_cache_key('entityone','*',where,'','','',params)
         one_row = self.get_dependency_cache(dependency_key,cache_key)
         if one_row and share_config.get_value("is_redis_cache",True) == True:
+            self.log_cache(dependency_key, cache_key, one_row, sql, params)
             if one_row == 'null':
                 return None
             return self._BaseModel__row_entity(one_row)
@@ -372,6 +389,7 @@ class CacheModel(BaseModel):
         cache_key = self.get_cache_key('total',field,where,group_by,'','',params)
         total = self.get_dependency_cache(dependency_key,cache_key)
         if total and share_config.get_value("is_redis_cache",True) == True:
+            self.log_cache(dependency_key, cache_key, total, sql, params)
             if total == '0':
                 return 0
             else:
@@ -417,6 +435,7 @@ class CacheModel(BaseModel):
         one_row = self.get_dependency_cache(dependency_key,cache_key)
 
         if one_row and share_config.get_value("is_redis_cache",True) == True:
+            self.log_cache(dependency_key, cache_key, one_row, sql, params)
             if one_row == 'null':
                 return None
             return one_row
@@ -449,6 +468,7 @@ class CacheModel(BaseModel):
         cache_key = self.get_cache_key('dictone',field,where,'','','',params)
         one_row = self.get_dependency_cache(dependency_key,cache_key)
         if one_row and share_config.get_value("is_redis_cache",True) == True:
+            self.log_cache(dependency_key, cache_key, one_row, sql, params)
             if one_row == 'null':
                 return None
             return one_row
@@ -491,6 +511,7 @@ class CacheModel(BaseModel):
         cache_key = self.get_cache_key('dictlist',field,where,group_by,order_by,limit,params)
         list = self.get_dependency_cache(dependency_key,cache_key)
         if list and share_config.get_value("is_redis_cache",True) == True:
+            self.log_cache(dependency_key, cache_key, list, sql, params)
             return list
         else:
             list_row = self.db.fetch_all_rows(sql, params)
@@ -536,6 +557,7 @@ class CacheModel(BaseModel):
         cache_key = self.get_cache_key('dictpagelist',field,where,group_by,order_by,limit,params)
         page_list = self.get_dependency_cache(dependency_key,cache_key)
         if page_list and share_config.get_value("is_redis_cache",True) == True:
+            self.log_cache(dependency_key, cache_key, page_list, sql, params)
             if page_count_mode == "total":
                 return page_list["data"],page_list["row_count"]
             elif page_count_mode == "next":
