@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2023-02-06 14:50:17
+@LastEditTime: 2023-03-23 18:44:52
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -100,8 +100,7 @@ class AssetConsoleModel():
             try:
                 time.sleep(0.1)
                 asset_warn_notice_model = AssetWarnNoticeModel()
-                message_system_db = int(config.get_value("message_system_db",100))
-                redis_init = SevenHelper.redis_init(message_system_db)
+                redis_init = SevenHelper.redis_init(config_dict=config.get_value("warn_redis"))
                 warn_notice_list = asset_warn_notice_model.get_list("is_notice=0 and ascription_type=1",order_by="create_date asc",limit="50")
                 if len(warn_notice_list) > 0:
                     for warn_notice in warn_notice_list:
