@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:55:09
-@LastEditTime: 2022-09-27 18:05:58
+@LastEditTime: 2023-03-13 11:22:34
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -32,6 +32,7 @@ class ActModule:
         self.business_type = 0  # 业务类型(0无1机台2活动)
         self.module_name = ""  # 模块名称
         self.module_sub_name = ""  # 模块短名称
+        self.module_type = 0  # 模块类型
         self.start_date = "1900-01-01 00:00:00"  # 开始时间
         self.end_date = "1900-01-01 00:00:00"  # 结束时间
         self.skin_id = 0  # 皮肤标识
@@ -63,7 +64,7 @@ class ActModule:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'business_type', 'module_name', 'module_sub_name', 'start_date', 'end_date', 'skin_id', 'module_pic', 'module_desc', 'price', 'price_gear_id', 'ip_id', 'join_ways', 'is_fictitious', 'sort_index', 'is_release', 'release_date', 'create_date', 'modify_date', 'is_del', 'i1', 'i2', 'i3', 'i4', 'i5', 's1', 's2', 's3', 's4', 's5', 'd1', 'd2']
+        return ['id', 'app_id', 'act_id', 'business_type', 'module_name', 'module_sub_name', 'module_type', 'start_date', 'end_date', 'skin_id', 'module_pic', 'module_desc', 'price', 'price_gear_id', 'ip_id', 'join_ways', 'is_fictitious', 'sort_index', 'is_release', 'release_date', 'create_date', 'modify_date', 'is_del', 'i1', 'i2', 'i3', 'i4', 'i5', 's1', 's2', 's3', 's4', 's5', 'd1', 'd2']
 
     @classmethod
     def get_primary_key(self):
