@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-06-02 14:32:40
-@LastEditTime: 2023-03-14 10:51:40
+@LastEditTime: 2023-03-16 10:40:36
 @LastEditors: HuangJianYi
 :description: 枚举类
 """
@@ -72,3 +72,5 @@ class TaskType(Enum):
     invite_user_help = 15
     # 神秘暗号，格式：{"reward_value":0,"secret_code":"","asset_object_id":""} 字段说明：reward_value:奖励值 secret_code:暗号 asset_object_id:资产对象标识
     secret_code = 16
+    # 店铺会员积分兑换资产，格式：{"reward_value":1,"satisfy_num":1,"limit_num":1} 字段说明：reward_value:奖励值 satisfy_num:需要的积分 limit_num:完成限制数
+    crm_point_exchange_asset = 17
