@@ -2,11 +2,12 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2023-02-06 11:49:58
+@LastEditTime: 2023-02-06 16:38:23
 @LastEditors: HuangJianYi
 @Description: 
 """
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.db_models.act.act_info_model import *
 from seven_cloudapp_frame.models.db_models.act.act_module_model import *
@@ -154,7 +155,7 @@ class FrameBaseModel():
 
     def get_business_sub_table(self, table_name, param_dict):
         """
-        :description: 获取分表名称
+        :description: 获取分表名称(目前框架支持的分表prize_order_tb、prize_roster_tb、stat_log_tb、task_count_tb、user_asset_tb、asset_log_tb、user_info_tb)
         :param table_name:表名
         :param param_dict:参数字典
         :return:
@@ -162,7 +163,7 @@ class FrameBaseModel():
         """
         if not param_dict or not table_name:
             return None    
-        sub_table_config = config.get_value("sub_table_config",{})
+        sub_table_config = share_config.get_value("sub_table_config",{})
         table_config = sub_table_config.get(table_name, None)
         if not table_config:
             return None
