@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-05 10:54:36
-@LastEditTime: 2022-10-17 14:17:30
+@LastEditTime: 2023-03-13 11:29:15
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -100,7 +100,7 @@ class ModuleBaseModel():
             page_list, total = ActModuleModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)
         return page_list, total
 
-    def save_act_module(self,app_id,act_id,module_id,module_name,module_sub_name,start_date,end_date,module_pic,module_desc,price,price_gear_id,ip_id,join_ways,is_fictitious,sort_index,is_release,i1,i2,i3,i4,i5,s1,s2,s3,s4,s5,d1,d2,business_type=0):
+    def save_act_module(self,app_id,act_id,module_id,module_name,module_sub_name,start_date,end_date,module_pic,module_desc,price,price_gear_id,ip_id,join_ways,is_fictitious,sort_index,is_release,i1,i2,i3,i4,i5,s1,s2,s3,s4,s5,d1,d2,business_type=0,module_type=0):
         """
         :description: 添加活动模块信息
         :param app_id: 应用标识
@@ -132,6 +132,8 @@ class ModuleBaseModel():
         :param s5: s5
         :param d1: d1
         :param d2: d2
+        :param business_type: 业务类型(0无1机台2活动)
+        :param module_type: 模块类型
         :return: 
         :last_editors: HuangJianYi
         """
@@ -164,6 +166,7 @@ class ModuleBaseModel():
         act_module.business_type = business_type
         act_module.module_name = module_name
         act_module.module_sub_name = module_sub_name
+        act_module.module_type = module_type
         act_module.start_date = start_date
         act_module.end_date = end_date
         act_module.module_pic = module_pic
