@@ -491,3 +491,14 @@ class DependencyKey():
         """
         return f"browse_log:actid_{act_id}_userid_{user_id}"
     
+    @classmethod
+    def invite_user_help_list(self, id_md5, user_id):
+        """
+        :description: 邀请用户助力记录
+        :param id_md5：id_md5
+        :param user_id：邀请人用户标识
+        :return str
+        :last_editors: HuangJianYi
+        """
+        return f"invite_help_list:{id_md5}_{user_id}"
+    
