@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2023-02-10 09:32:11
+@LastEditTime: 2023-02-16 15:44:37
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -109,7 +109,7 @@ class StatBaseModel(FrameBaseModel):
             for stat_queue in stat_queue_list:
                 redis_init.rpush(f"stat_queue_list:{str(user_id % 10)}", SevenHelper.json_dumps(stat_queue))
 
-    def get_stat_report_list(self, app_id, act_id, module_id, start_date, end_date, order_by="sort_index asc", is_only_module=False, orm_condition=None, orm_params=None):
+    def get_stat_report_list(self, app_id, act_id, module_id, start_date, end_date, order_by="sort_index asc", is_only_module=False, orm_condition=None, orm_params=None, report_condition=None, report_params=None):
         """
         :description: 报表数据列表(表格)
         :param app_id：应用标识
@@ -121,17 +121,21 @@ class StatBaseModel(FrameBaseModel):
         :param is_only_module：是否只取module的数据
         :param orm_condition：orm查询条件
         :param orm_params：orm参数数组
+        :param report_condition：report查询条件
+        :param report_params：report参数数组
         :return list
         :last_editors: HuangJianYi
         """
-        report_condition = "app_id=%s and act_id=%s and module_id=%s"
-        params = [app_id,act_id,module_id]
+        if not report_condition:
+            report_condition = "app_id=%s and act_id=%s and module_id=%s"
+        if not report_params:
+            report_params = [app_id,act_id,module_id]
         if start_date != "":
             report_condition += " and create_date>=%s"
-            params.append(start_date)
+            report_params.append(start_date)
         if end_date != "":
             report_condition += " and create_date<%s"
-            params.append(end_date)
+            report_params.append(end_date)
         if is_only_module == True:
             if not orm_condition:
                 orm_condition = "act_id=%s and module_id=%s and is_show=1"
@@ -142,13 +146,13 @@ class StatBaseModel(FrameBaseModel):
                 orm_condition = "((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and is_show=1"
             if not orm_params:
                 orm_params = [act_id,module_id]
-        stat_orm_list = StatOrmModel(context=self.context).get_list(where=orm_condition,group_by="key_name", order_by=order_by, params=orm_params)
+        stat_orm_list = StatOrmModel(context=self.context).get_list(where=orm_condition, group_by="key_name", order_by=order_by, params=orm_params)
         if len(stat_orm_list)<=0:
             return []
         key_name_s = ','.join(["'%s'" % str(stat_orm.key_name) for stat_orm in stat_orm_list])
         report_condition += f" and key_name in({key_name_s})"
         stat_report_model = StatReportModel(context=self.context)
-        behavior_report_list = stat_report_model.get_dict_list(report_condition, group_by="key_name", field="key_name,SUM(key_value) AS key_value",params=params)
+        behavior_report_list = stat_report_model.get_dict_list(report_condition, group_by="key_name", field="key_name,SUM(key_value) AS key_value",params=report_params)
         #公共映射组（未去重）
         common_groups_1 = [orm.group_name for orm in stat_orm_list]
         #公共映射组(去重)
@@ -214,7 +218,7 @@ class StatBaseModel(FrameBaseModel):
 
         return common_group_data_list
 
-    def get_trend_report_list(self, app_id, act_id, module_id, start_date, end_date, order_by="sort_index asc", is_only_module=False, orm_condition=None, orm_params=None):
+    def get_trend_report_list(self, app_id, act_id, module_id, start_date, end_date, order_by="sort_index asc", is_only_module=False, orm_condition=None, orm_params=None, report_condition=None, report_params=None):
         """
         :description: 报表数据列表(趋势图)
         :param app_id：应用标识
@@ -226,17 +230,21 @@ class StatBaseModel(FrameBaseModel):
         :param is_only_module：是否只取module的数据
         :param orm_condition：orm查询条件
         :param orm_params：orm参数数组
+        :param report_condition：report查询条件
+        :param report_params：report参数数组
         :return list
         :last_editors: HuangJianYi
         """
-        condition = "app_id=%s and act_id=%s and module_id=%s"
-        params = [app_id,act_id,module_id]
+        if not report_condition:
+            report_condition = "app_id=%s and act_id=%s and module_id=%s"
+        if not report_params:
+            report_params = [app_id,act_id,module_id]
         if start_date != "":
-            condition += " and create_date>=%s"
-            params.append(start_date)
+            report_condition += " and create_date>=%s"
+            report_params.append(start_date)
         if end_date != "":
-            condition += " and create_date<%s"
-            params.append(end_date)
+            report_condition += " and create_date<%s"
+            report_params.append(end_date)
         if is_only_module == True:
             if not orm_condition:
                 orm_condition = "act_id=%s and module_id=%s and is_show=1"
@@ -247,13 +255,13 @@ class StatBaseModel(FrameBaseModel):
                 orm_condition = "((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and is_show=1"
             if not orm_params:
                 orm_params = [act_id, module_id]
-        stat_orm_list = StatOrmModel(context=self.context).get_list(where=orm_condition, order_by=order_by, params=orm_params)
+        stat_orm_list = StatOrmModel(context=self.context).get_list(where=orm_condition, group_by="key_name", order_by=order_by, params=orm_params)
         if len(stat_orm_list)<=0:
             return []
         key_name_s = ','.join(["'%s'" % str(stat_orm.key_name) for stat_orm in stat_orm_list])
-        condition += f" and key_name in({key_name_s})"
+        report_condition += f" and key_name in({key_name_s})"
         stat_report_model = StatReportModel(context=self.context)
-        stat_report_list = stat_report_model.get_dict_list(condition, field="key_name,key_value,DATE_FORMAT(create_date,'%%Y-%%m-%%d') AS create_date",params=params)
+        stat_report_list = stat_report_model.get_dict_list(report_condition, field="key_name,key_value,DATE_FORMAT(create_date,'%%Y-%%m-%%d') AS create_date",params=report_params)
         date_list = SevenHelper.get_date_list(start_date, end_date)
         #公共映射组（未去重）
         common_groups_1 = [orm.group_name for orm in stat_orm_list]
@@ -425,7 +433,6 @@ class StatBaseModel(FrameBaseModel):
 
         return invoke_result_data
 
-
     def add_stat_user_list(self, app_id, act_id, module_id, user_id, open_id, stat_data):
         """
         :description: 添加用户行为上报
