@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2023-01-16 11:08:01
+@LastEditTime: 2023-02-16 17:56:48
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -83,8 +83,6 @@ def seven_cloudapp_frame_route():
         (r"/server/left_navigation", base_s.LeftNavigationHandler),  #左侧导航
         (r"/server/friend_link_list", base_s.FriendLinkListHandler),  #获取友情链接产品互推列表
         (r"/server/send_sms", base_s.SendSmsHandler),  #发短信
-        (r"/server/cms_info_list", base_s.CmsInfoListHandler),  #位置信息列表
-        (r"/server/save_cms_info", base_s.SaveCmsInfoHandler),  #保存位置信息
         (r"/server/get_product_price", base_s.GetProductPriceHandler),  #获取产品价格信息
         (r"/server/get_high_power_list", app_s.GetHighPowerListHandler),  #获取中台配置的高级权限列表
         (r"/server/app_info", app_s.AppInfoHandler),  #应用信息
@@ -97,6 +95,8 @@ def seven_cloudapp_frame_route():
         (r"/server/update_store_asset", app_s.UpdateStoreAssetHandler),  #更新商家资产值
         (r"/server/store_asset_list", app_s.StoreAssetListHandler),  #商家资产列表
         (r"/server/store_asset_log_list", app_s.StoreAssetLogListHandler),  #商家资产流水列表
+        (r"/server/cms_info_list", cms_s.CmsInfoListHandler),  #获取资讯列表
+        (r"/server/save_cms_info", cms_s.SaveCmsInfoHandler),  #保存资讯信息
         (r"/server/act_type_list", act_s.ActTypeListHandler),  #活动类型列表
         (r"/server/next_progress", act_s.NextProgressHandler),  #活动下一步操作
         (r"/server/add_act_info", act_s.AddActInfoHandler),  #添加活动
@@ -167,8 +167,8 @@ def seven_cloudapp_frame_route():
         (r"/server/goods_list_by_goodsids", goods_s.GoodsListByGoodsIDHandler),  #根据商品ID返回在售中商品列表
         (r"/server/goods_info", goods_s.GoodsInfoHandler),  #商品信息
         (r"/server/benefit_detail", goods_s.BenefitDetailHandler),  #获取优惠券详情信息
-        (r"/server/task_info_list", task_s.TaskInfoListHandler),  #任务信息列表
-        (r"/server/save_task_info", task_s.SaveTaskInfoHandler),  #保存任务信息
         (r"/server/special_goods_list", goods_s.SpecialGoodsListHandler),  #专属下单商品列表
         (r"/server/bind_special_goods", goods_s.BindSpecialGoodsHandler),  #专属下单商品绑定
+        (r"/server/cms_info_list", cms_s.CmsInfoListHandler),  #获取资讯列表
+        (r"/server/save_cms_info", cms_s.SaveCmsInfoHandler),  #保存资讯信息
     ]
\ No newline at end of file
